{
    "$graph": [
        {
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "class": "ExpressionTool",
            "inputs": [
                {
                    "id": "#emit_file_format.cwl/input",
                    "type": "File"
                },
                {
                    "id": "#emit_file_format.cwl/format",
                    "type": "string"
                }
            ],
            "expression": "${\n  var output = inputs.input;\n  output.format = inputs.format;\n  return {'output': output}\n}\n",
            "id": "#emit_file_format.cwl",
            "outputs": [
                {
                    "id": "#emit_file_format.cwl/output",
                    "type": "File"
                }
            ]
        },
        {
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/ncigdc/samtools:147bd4cc606a63c7435907d97fea6e94e9ea9ed58c18f390cab8bc40b1992df7"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "$(inputs.input.basename)",
                            "entry": "$(inputs.input)"
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 1,
                    "ramMin": 5000,
                    "ramMax": 5000,
                    "tmpdirMin": 50,
                    "tmpdirMax": 50,
                    "outdirMin": 50,
                    "outdirMax": 50
                }
            ],
            "class": "CommandLineTool",
            "inputs": [
                {
                    "id": "#samtools_index.cwl/input",
                    "type": "File",
                    "format": "#samtools_index.cwl/format_2572"
                },
                {
                    "id": "#samtools_index.cwl/thread_count",
                    "type": "long",
                    "inputBinding": {
                        "prefix": "-@",
                        "position": 0
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#samtools_index.cwl/output",
                    "type": "File",
                    "format": "#samtools_index.cwl/format_2572",
                    "outputBinding": {
                        "glob": "$(inputs.input.basename)"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.input.basename)",
                    "position": 1
                },
                {
                    "valueFrom": "$(inputs.input.nameroot + \".bai\")",
                    "position": 2
                }
            ],
            "baseCommand": [
                "/usr/local/bin/samtools",
                "index"
            ],
            "id": "#samtools_index.cwl"
        },
        {
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:bionic-20180426"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 1,
                    "ramMin": 250,
                    "ramMax": 250,
                    "tmpdirMin": 1,
                    "tmpdirMax": 1,
                    "outdirMin": 1,
                    "outdirMax": 1
                }
            ],
            "class": "CommandLineTool",
            "inputs": [
                {
                    "id": "#touch.cwl/input",
                    "type": "string",
                    "inputBinding": {
                        "position": 0
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#touch.cwl/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input)"
                    }
                }
            ],
            "baseCommand": [
                "touch"
            ],
            "id": "#touch.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/bam",
                    "type": "File"
                },
                {
                    "id": "#main/thread_count",
                    "type": "long"
                }
            ],
            "outputs": [
                {
                    "id": "#main/output",
                    "type": "File",
                    "outputSource": "#main/samtools_index/output"
                },
                {
                    "id": "#main/sqlite",
                    "type": "File",
                    "outputSource": "#main/format_sqlite/output"
                }
            ],
            "steps": [
                {
                    "id": "#main/samtools_index",
                    "run": "#samtools_index.cwl",
                    "in": [
                        {
                            "id": "#main/samtools_index/input",
                            "source": "#main/bam"
                        },
                        {
                            "id": "#main/samtools_index/thread_count",
                            "source": "#main/thread_count"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/samtools_index/output"
                        }
                    ]
                },
                {
                    "id": "#main/empty_sqlite",
                    "run": "#touch.cwl",
                    "in": [
                        {
                            "id": "#main/empty_sqlite/input",
                            "valueFrom": "empty.sqlite"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/empty_sqlite/output"
                        }
                    ]
                },
                {
                    "id": "#main/format_sqlite",
                    "run": "#emit_file_format.cwl",
                    "in": [
                        {
                            "id": "#main/format_sqlite/input",
                            "source": "#main/empty_sqlite/output"
                        },
                        {
                            "id": "#main/format_sqlite/format",
                            "valueFrom": "edam:format_2572"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/format_sqlite/output"
                        }
                    ]
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
